pub struct RangeSchema {
pub kind: RangeKind,
pub cell_type: ValueType,
pub format: Option<String>,
}Fields
kind: RangeKindcell_type: ValueTypeValue type enforced for each cell.
format: Option<String>Trait Implementations
Sourceimpl Clone for RangeSchema
impl Clone for RangeSchema
Sourcefn clone(&self) -> RangeSchema
fn clone(&self) -> RangeSchema
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RangeSchema
impl Debug for RangeSchema
Sourceimpl<'de> Deserialize<'de> for RangeSchema
impl<'de> Deserialize<'de> for RangeSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RangeSchema
impl JsonSchema for RangeSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RangeSchema
impl RefUnwindSafe for RangeSchema
impl Send for RangeSchema
impl Sync for RangeSchema
impl Unpin for RangeSchema
impl UnwindSafe for RangeSchema