pub struct RecordField {
pub value_type: ValueType,
pub location: FieldSelector,
pub constraints: Option<Constraints>,
pub units: Option<Units>,
}Fields
value_type: ValueTypeScalar value type for the field.
location: FieldSelectorSelector resolving to the field cell.
constraints: Option<Constraints>units: Option<Units>Trait Implementations
Sourceimpl Clone for RecordField
impl Clone for RecordField
Sourcefn clone(&self) -> RecordField
fn clone(&self) -> RecordField
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecordField
impl Debug for RecordField
Sourceimpl<'de> Deserialize<'de> for RecordField
impl<'de> Deserialize<'de> for RecordField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecordField
impl JsonSchema for RecordField
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecordField
impl RefUnwindSafe for RecordField
impl Send for RecordField
impl Sync for RecordField
impl Unpin for RecordField
impl UnwindSafe for RecordField