pub struct TableColumn {
pub name: String,
pub value_type: ValueType,
pub col: Option<String>,
pub format: Option<String>,
pub units: Option<Units>,
}Fields
name: StringColumn name exposed to clients.
value_type: ValueTypeScalar type for column cells.
col: Option<String>Optional column letter hint when using layout selectors.
format: Option<String>units: Option<Units>Trait Implementations
Sourceimpl Clone for TableColumn
impl Clone for TableColumn
Sourcefn clone(&self) -> TableColumn
fn clone(&self) -> TableColumn
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableColumn
impl Debug for TableColumn
Sourceimpl<'de> Deserialize<'de> for TableColumn
impl<'de> Deserialize<'de> for TableColumn
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TableColumn
impl JsonSchema for TableColumn
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TableColumn
impl RefUnwindSafe for TableColumn
impl Send for TableColumn
impl Sync for TableColumn
impl Unpin for TableColumn
impl UnwindSafe for TableColumn